@@ -33,6 +33,13 @@ ignored_re = re.compile(
     "|".join(
         [
             r"^parameters are mutually exclusive:",
+            # https://github.com/ansible/ansible-lint/issues/3128 as strings can be jinja
+            # Do not remove unless you manually test if the original example
+            # from the bug does not trigger the rule anymore. We were not able
+            # to add a regression test because it would involve installing this
+            # collection. Attempts to reproduce same bug with other collections
+            # failed, even if the message originates from Ansible core.
+            r"^unable to evaluate string as dictionary$",
         ]
     ),
     flags=re.MULTILINE | re.DOTALL,
@@ -42,7 +49,8 @@ workarounds_drop_map = {
     # https://github.com/ansible/ansible-lint/issues/3110
     "ansible.builtin.copy": ["decrypt"],
     # https://github.com/ansible/ansible-lint/issues/2824#issuecomment-1354337466
-    "ansible.builtin.service": ["daemon_reload"],
+    # https://github.com/ansible/ansible-lint/issues/3138
+    "ansible.builtin.service": ["daemon_reload", "use"],
     # Avoid: Unsupported parameters for (basic.py) module: cmd. Supported parameters include: _raw_params, _uses_shell, argv, chdir, creates, executable, removes, stdin, stdin_add_newline, strip_empty_ends.
     "ansible.builtin.command": ["cmd"],
 }
@@ -249,7 +257,7 @@ if "pytest" in sys.modules:
         assert results[2].tag == "args[module]"
         assert "Unsupported parameters for" in results[2].message
         assert results[3].tag == "args[module]"
-        assert "Unsupported parameters for" in results[2].message
+        assert "Unsupported parameters for" in results[3].message
         assert results[4].tag == "args[module]"
         assert "value of state must be one of" in results[4].message
 
