@@ -11,7 +11,8 @@ from ansible.parsing.yaml.objects import AnsibleUnicode
 from ansiblelint.config import options
 from ansiblelint.constants import LINE_NUMBER_KEY, SUCCESS_RC
 from ansiblelint.file_utils import Lintable
-from ansiblelint.rules import AnsibleLintRule
+from ansiblelint.rules import AnsibleLintRule, RulesCollection
+from ansiblelint.runner import Runner
 from ansiblelint.skip_utils import get_rule_skips_from_line
 from ansiblelint.utils import parse_yaml_from_file
 
@@ -30,18 +31,12 @@ CamelCaseButErrorIgnored: true  # noqa: var-naming
 """
 
 
-# properties/parameters are prefixed and postfixed with `__`
-def is_property(k: str) -> bool:
-    """Check if key is a property."""
-    return k.startswith("__") and k.endswith("__")
-
-
 class VariableNamingRule(AnsibleLintRule):
     """All variables should be named using only lowercase and underscores."""
 
     id = "var-naming"
     severity = "MEDIUM"
-    tags = ["idiom", "experimental"]
+    tags = ["idiom"]
     version_added = "v5.0.10"
     needs_raw_task = True
     re_pattern = re.compile(options.var_naming_pattern or "^[a-z_][a-z0-9_]*$")
@@ -49,7 +44,7 @@ class VariableNamingRule(AnsibleLintRule):
     def is_invalid_variable_name(self, ident: str) -> bool:
         """Check if variable name is using right pattern."""
         # Based on https://github.com/ansible/ansible/blob/devel/lib/ansible/utils/vars.py#L235
-        if not isinstance(ident, str):
+        if not isinstance(ident, str):  # pragma: no cover
             return False
 
         try:
@@ -74,7 +69,7 @@ class VariableNamingRule(AnsibleLintRule):
         results: list[MatchError] = []
         raw_results: list[MatchError] = []
 
-        if not data:
+        if not data or file.kind not in ("tasks", "handlers", "playbook", "vars"):
             return results
         # If the Play uses the 'vars' section to set variables
         our_vars = data.get("vars", {})
@@ -184,7 +179,6 @@ class VariableNamingRule(AnsibleLintRule):
 
 # testing code to be loaded only with pytest or when executed the rule file
 if "pytest" in sys.modules:
-
     import pytest
 
     from ansiblelint.testing import (  # pylint: disable=ungrouped-imports
@@ -193,12 +187,19 @@ if "pytest" in sys.modules:
     )
 
     @pytest.mark.parametrize(
-        "rule_runner", (VariableNamingRule,), indirect=["rule_runner"]
+        ("file", "expected"),
+        (
+            pytest.param("examples/playbooks/rule-var-naming-fail.yml", 7, id="0"),
+            pytest.param("examples/Taskfile.yml", 0, id="1"),
+        ),
     )
-    def test_invalid_var_name_playbook(rule_runner: RunFromText) -> None:
+    def test_invalid_var_name_playbook(file: str, expected: int) -> None:
         """Test rule matches."""
-        results = rule_runner.run("examples/playbooks/rule-var-naming-fail.yml")
-        assert len(results) == 7
+        rules = RulesCollection(options=options)
+        rules.register(VariableNamingRule())
+        results = Runner(Lintable(file), rules=rules).run()
+        # results = rule_runner.run()
+        assert len(results) == expected
         for result in results:
             assert result.rule.id == VariableNamingRule.id
         # We are not checking line numbers because they can vary between
@@ -233,3 +234,9 @@ if "pytest" in sys.modules:
         )
         assert result.returncode == SUCCESS_RC
         assert "var-naming" not in result.stdout
+
+    def test_is_invalid_variable_name() -> None:
+        """Test for invalid variable names."""
+        var_name_rule = VariableNamingRule()
+        assert var_name_rule.is_invalid_variable_name("assert") is False
+        assert var_name_rule.is_invalid_variable_name("é") is False
