@@ -24,8 +24,9 @@ import logging
 import subprocess
 import sys
 from argparse import Namespace
+from collections.abc import Sequence
 from pathlib import Path
-from typing import Any, Sequence
+from typing import Any
 
 import pytest
 from _pytest.capture import CaptureFixture
@@ -39,6 +40,8 @@ from ansiblelint.__main__ import initialize_logger
 from ansiblelint.cli import get_rules_dirs
 from ansiblelint.constants import VIOLATIONS_FOUND_RC
 from ansiblelint.file_utils import Lintable
+from ansiblelint.rules import RulesCollection
+from ansiblelint.runner import Runner
 
 runtime = Runtime(require_module=True)
 
@@ -145,11 +148,11 @@ def test_normalize_complex_command() -> None:
                 "action": {
                     "__ansible_module__": "yum",
                     "__ansible_module_original__": "yum",
-                    "__ansible_arguments__": [],
                     "name": "httpd",
                     "state": "latest",
                 },
             },
+            id="0",
         ),
         pytest.param(
             {
@@ -176,6 +179,7 @@ def test_normalize_complex_command() -> None:
                     "__ansible_module_original__": "block/always/rescue",
                 },
             },
+            id="1",
         ),
     ),
 )
@@ -294,13 +298,16 @@ def test_cli_auto_detect(capfd: CaptureFixture[str]) -> None:
     # An expected rule match from our examples
     assert (
         "examples/playbooks/empty_playbook.yml:1:1: "
-        "warning[empty-playbook]: Empty playbook, nothing to do" in out
+        "syntax-check[empty-playbook]: Empty playbook, nothing to do" in out
     )
     # assures that our ansible-lint config exclude was effective in excluding github files
     assert "Identified: .github/" not in out
     # assures that we can parse playbooks as playbooks
     assert "Identified: test/test/always-run-success.yml" not in err
-    assert "Executing syntax check on examples/playbooks/mocked_dependency.yml" in err
+    assert (
+        "Executing syntax check on playbook examples/playbooks/mocked_dependency.yml"
+        in err
+    )
 
 
 def test_is_playbook() -> None:
@@ -369,24 +376,14 @@ def test_get_rules_dirs_with_custom_rules(
     assert get_rules_dirs(user_ruledirs, use_default) == expected
 
 
-def test_nested_items() -> None:
-    """Verify correct function of nested_items()."""
-    data = {"foo": "text", "bar": {"some": "text2"}, "fruits": ["apple", "orange"]}
-
-    items = [
-        ("foo", "text", ""),
-        ("bar", {"some": "text2"}, ""),
-        ("some", "text2", "bar"),
-        ("fruits", ["apple", "orange"], ""),
-        ("list-item", "apple", "fruits"),
-        ("list-item", "orange", "fruits"),
-    ]
-    with pytest.deprecated_call(
-        match=r"Call to deprecated function ansiblelint\.utils\.nested_items.*"
-    ):
-        assert list(utils.nested_items(data)) == items
-
-
 def test_find_children() -> None:
     """Verify correct function of find_children()."""
     utils.find_children(Lintable("examples/playbooks/find_children.yml"))
+
+
+def test_find_children_in_task(default_rules_collection: RulesCollection) -> None:
+    """Verify correct function of find_children() in tasks."""
+    Runner(
+        Lintable("examples/playbooks/tasks/bug-2875.yml"),
+        rules=default_rules_collection,
+    ).run()
